/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

/////////////////////////////////////////////////////////////////////////////////////
#include "acoparams.h"
/////////////////////////////////////////////////////////////////////////////////////

AcoParams::AcoParams() {
	alpha = 1.0;
	beta = 5.0;
	rho = 0.5;
	q = 10.0;
	n_replicate = 100;
	n_ant = 20;
	n_city = 0;
	init_tau = 0.00000001;
	p_fancy = 0.005;
	weight = 2.0;
};

void AcoParams::setAlpha(double d) {
	alpha = d;
}

double AcoParams::getAlpha() {
	return alpha;
}

void AcoParams::setBeta(double d) {
	beta = d;
}

double AcoParams::getBeta() {
	return beta;
}

void AcoParams::setRho(double d) {
	rho = d;
}

double AcoParams::getRho() {
	return rho;
}

void AcoParams::setQ(double d) {
	q = d;
}

double AcoParams::getQ() {
	return q;
}

void AcoParams::setN_replicate(int i) {
	n_replicate = i;
}

int AcoParams::getN_replicate() {
	return n_replicate;
}

void AcoParams::setN_ant(int i) {
	n_ant = i;
}

int AcoParams::getN_ant() {
	return n_ant;
}

void AcoParams::setN_city(int i) {
	n_city = i;
}

int AcoParams::getN_city() {
	return n_city;
}

void AcoParams::setInit_tau(double d) {
	init_tau = d;
}

double AcoParams::getInit_tau() {
	return init_tau;
}

void AcoParams::setP_fancy(double d) {
	p_fancy = d;
}

double AcoParams::getP_fancy() {
	return p_fancy;
}

void AcoParams::setWeight(double d) {
	weight = d;
}

double AcoParams::getWeight() {
	return weight;
}

bool AcoParams::isRandomize() {
	if(p_fancy == 0) {
		return false;
	}
	return true;
}
