/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

#include <iostream>
#include <vector>
#include <time>

#include "acoparams.h"
#include "antcolony.h"
#include "tourinfo.h"

using namespace std;

main(void) {
	int n_city = 6;
	double dist[36] = {0.0, 1.0, 2.0, 3.0, 4.0, 5.0,
					   1.0, 0.0, 1.0, 2.0, 3.0, 4.0,
					   2.0, 1.0, 0.0, 1.0, 2.0, 3.0,
					   3.0, 2.0, 1.0, 0.0, 1.0, 2.0,
					   4.0, 3.0, 2.0, 1.0, 0.0, 1.0,
					   5.0, 4.0, 3.0, 2.0, 1.0, 0.0};
	long start, end;
	time(&start);
	AcoParams params;
	params.setN_city(n_city);
	params.setN_replicate(100000);
	AntColony antColony(&params, dist, 1);
	TourInfo bestTour = antColony.findBestTour();
	cout << "Tour Length: " << bestTour.getTourLength() << endl;
	vector<int> tourOrder = bestTour.getTourOrder();
	cout << "Tour Order: " << endl;
	for(int i = 0; i < n_city; i++ ) {
		cout << " " << tourOrder[i];
	}
	cout << endl;
	time(&end);
	cout << end - start << endl;
}