/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

//#include <windows.h>
//#include <iostream>
#include <vector>

#include "acoparams.h"
#include "antcolony.h"
#include "tourinfo.h"
#include "org_agmodel_bioinfo_antmap_AntColonyJNI.h"

using namespace std;

JNIEXPORT jdouble JNICALL Java_org_agmodel_bioinfo_antmap_AntColonyJNI_findBestTour
  (JNIEnv *env,
   jobject caller,
   jdouble alpha,
   jdouble beta,
   jdouble rho,
   jdouble q,
   jint n_replicate,
   jint n_ant,
   jdouble init_tau,
   jdouble p_fancy,
   jdouble weight,
   jdoubleArray dist_1d,
   jintArray order)
{
	jfieldID fldid;
	
	if(caller == NULL) {
		return -1.0;
	}
	if((fldid = env->GetFieldID(env->GetObjectClass(caller), "seed", "J")) == NULL) {
		return -1.0;
	}

	AcoParams params;
	params.setAlpha(alpha);
	params.setBeta(beta);
	params.setRho(rho);
	params.setQ(q);
	params.setN_replicate((int)n_replicate);
	params.setN_ant((int)n_ant);
	params.setInit_tau(init_tau);
	params.setP_fancy(p_fancy);
	params.setWeight(weight);
	double *dist = env->GetDoubleArrayElements(dist_1d, NULL);
	long *tourOrder = env->GetIntArrayElements(order, NULL);
	int n_city = env->GetArrayLength(order);
	params.setN_city(n_city);

	unsigned long seed = env->GetLongField(caller, fldid);
	AntColony antColony(&params, dist, seed);
	TourInfo bestTour = antColony.findBestTour();
	vector<int> bestOrder = bestTour.getTourOrder();
	for(int i = 0; i < n_city; i++ ) {
		tourOrder[i] = bestOrder[i];
	}
	seed = antColony.getNextSeed();
	env->SetLongField(caller, fldid, seed);
	
	env->ReleaseDoubleArrayElements(dist_1d, dist, 0);
	env->ReleaseIntArrayElements(order, tourOrder, 0);
	return bestTour.getTourLength();
}
