/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap;

//import org.agmodel.bioinfo.segregation.MapFunction;

/**
 * @author iwata
 *
 */
public class AcoMapFactory {
	private AcoParamsBean acoParams;

	public AcoMapFactory(AcoParamsBean acoParams) {
		this.acoParams = acoParams;
	}

	public MapData getBestMap(SegDataBean segDataBean, int [] markerIndex, int maxIteration, int n_confirm) {
		double [][] r = new RMatrixFactory().getR(segDataBean, markerIndex);
		AntColonyOptimizer aco = new ACOFactory().getAntColonyOptimizer(acoParams, r);
		TourBean bestTour = new TourBean();
		int count = 0;
		for(int i = 0; i < maxIteration; i++ ) {
			TourBean tempTour = aco.findBestTour();
			System.out.println("Tour Length " + (i + 1) + ": " + tempTour.getTourLength());
			if(bestTour.getTourLength() == tempTour.getTourLength())
				count ++;
			else if(bestTour.getTourLength() > tempTour.getTourLength())
				bestTour = tempTour;
			if(count == n_confirm)
				break;
		}
		new OrderAligner().align(bestTour.getTourOrder(), r);
		MapData mapData = new MapData(markerIndex, bestTour.getTourOrder(), new PartialExtractor().extractParitalArray(segDataBean.getMarkerName(), markerIndex), r);
		return mapData;
	}

	public TourBean getBootStrapMap(SegDataBean segDataBean, int [] markerIndex, int maxIteration, int n_confirm) {
		double [][] r = new RMatrixFactory().getBootStrappedR(segDataBean, markerIndex);
		AntColonyOptimizer aco = new ACOFactory().getAntColonyOptimizer(acoParams, r);
		TourBean bestTour = new TourBean();
		int count = 0;
		for(int i = 0; i < maxIteration; i++ ) {
			TourBean tempTour = aco.findBestTour();
			if(bestTour.getTourLength() == tempTour.getTourLength())
				count ++;
			else if(bestTour.getTourLength() > tempTour.getTourLength())
				bestTour = tempTour;
			if(count == n_confirm)
				break;
		}
		new OrderAligner().align(bestTour.getTourOrder(), r);
		return bestTour;
	}

	/**
	 * @return
	 */
	public AcoParamsBean getAcoParams() {
		return acoParams;
	}

	/**
	 * @param bean
	 */
	public void setAcoParams(AcoParamsBean bean) {
		acoParams = bean;
	}

}
