/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap;

/**
 * @author iwata
 *
 * ̐ꂽRg̑}ev[gύX邽
 * EBhE > ݒ > Java > R[h > R[hƃRg
 */
public class AntColony_GR {
	private double [][] eta;
	private double [][] tau;
	private AcoParamsBean params;
	private Ant_GR [] ant;
	int n_city;
	TourBean bestTour = new TourBean();

	/**
	 * RXgN^
	 * @param params ACOp[^
	 * @param eta seta
	 */
	public AntColony_GR(AcoParamsBean params, double [][] dist) {
		this.params = params;
		eta = new EMatrixFactory().convertD2E(dist);
		n_city = eta.length;
		tau = new double[n_city][n_city];
		ant = new Ant_GR[params.getN_ant()];
		for(int i = 0; i < ant.length; i++ ) {
			ant[i] = new Ant_GR(params, eta, tau);
		}
	}

	/**
	 * AntColonypŗǃcA[̒Ts
	 * @ return ŗǃcA[
	 */
	public TourBean findBestTour() {
		initTau();
		TourBean tempBest;
		int n_iteration = params.getN_iteration();
		for(int i = 0; i < n_iteration; i++ ) {
			tempBest = sendAntsOnJourney();
			if(tempBest.getTourLength() < bestTour.getTourLength()) {
				bestTour = tempBest;
			}
			updatePheromoneLevel();
		}
		return bestTour;
	}

	/**
	 * Aɗ
	 * @return _ł̍ŗǃcA[̓̂
	 */
	private TourBean sendAntsOnJourney() {
		TourBean tempTour;
		TourBean tempBest = new TourBean();

		for(int i = 0; i < ant.length; i++ ) {
			tempTour = ant[i].makeTour();
			if(tempTour.getTourLength() < tempBest.getTourLength()) {
				tempBest = tempTour;
			}
		}
		return tempBest;
	}

	/**
	 * tFXV
	 *
	 */
	private void updatePheromoneLevel() {
		double rho = params.getRho();
		for(int i = 0; i < n_city; i++ )
			for(int j = 0; j < n_city; j++ )
				tau[i][j] *= rho;
		for(int i = 0; i < ant.length; i++ )
			ant[i].secretePheromone();

		markBestTour();
	}

	/**
	 * ŗǂ̃cA[}[N
	 *
	 */
	private void markBestTour() {
		double delta_tau = 0.0;
		double weight = params.getWeight();
		double tourLength = bestTour.getTourLength();
		int [] tourOrder = bestTour.getTourOrder();
		int terminal = n_city - 1;
		if(tourLength > 0)
			delta_tau = params.getQ() / tourLength;
		for(int i = 1; i < tourOrder.length; i++ ) {
			tau[tourOrder[i - 1]][tourOrder[i]] += delta_tau * weight;
			tau[tourOrder[i]][tourOrder[i - 1]] += delta_tau * weight;
		}
		tau[tourOrder[0]][terminal] += delta_tau * weight; //mark starting point
		tau[terminal][tourOrder[0]] += delta_tau * weight;
		tau[tourOrder[tourOrder.length - 1]][terminal] += delta_tau * weight; //mark end point
		tau[terminal][tourOrder[tourOrder.length - 1]] += delta_tau * weight;
	}

	private void initTau() {
		double init_tau = params.getInit_tau();
		for(int i = 0; i < tau.length; i++ )
			for(int j = 0; j < tau[0].length; j++ )
				tau[i][j] = init_tau;
	}
}
