/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap;

import java.util.Random;

/**
 * @author iwata
 *
 * ̐ꂽRg̑}ev[gύX邽
 * EBhE > ݒ > Java > R[h > R[hƃRg
 */
public class Ant_Old {
	private AcoParamsBean params;
	private double [][] eta;
	private double [][] tau;
	private int [] isNotVisited;
	private double [] p;
	private int n_city = 0;
	private int currentCity = 0;
	private double tourLength = 0.0;
	private int [] tourOrder;
	static private Random rand = new Random();

	/**
	 * RXgN^
	 * @param params ACOp[^
	 * @param eta seta
	 * @param tau stau
	 */
	public Ant_Old(AcoParamsBean params, double [][] eta, double [][] tau) {
		this.params = params;  //ep[^
		this.eta = eta;
		this.tau = tau;
		n_city = eta[0].length;  //ss̎擾
		isNotVisited = new int[n_city];  //KsstO̐ݒ
		for(int i = 0; i < n_city; i ++) {
			isNotVisited[i] = 1;
		}
		tourOrder = new int [n_city];
		p = new double[n_city];  //ess̑I𗦁ia1ɊĂȂj
	}

	/*
	public int getRand() {
		return rand.nextInt();
	}
	*/

	/**
	 * cA[s
	 * @return cA[s
	 */
	public TourBean makeTour() {
        /*
         * ̏
         */
		for(int i = 0; i < n_city; i++ ) {  //KsstÕZbg
			isNotVisited[i] = 1;
		}
		tourLength = 0.0;

		/*
		 * K̗
		 */
		boolean randomize = params.isRandomize();
		double p_fancy = params.getP_fancy();
		if(randomize && (rand.nextDouble() < p_fancy))
			currentCity = selectStartPointRandomly();
		else
			currentCity = selectStartPoint();
		tourOrder[0] = currentCity;
		isNotVisited[currentCity] = 0;
		for(int i = 1; i < n_city; i++ ) {
			int lastCity = currentCity;
			if(randomize && (rand.nextDouble() < p_fancy))
				currentCity = selectNextStopRandomly();
			else
				currentCity = selectNextStop();
			tourOrder[i] = currentCity;
			isNotVisited[currentCity] = 0;
			tourLength += 1 / eta[lastCity][currentCity];
		}

		return new TourBean(tourLength, tourOrder);
	}

	/**
	 * tFo
	 */
	public void secretePheromone() {
		double delta_tau = 0.0;
		if(tourLength > 0)
			delta_tau = params.getQ() / tourLength;
		for(int i = 1; i < tourOrder.length; i++ ) {
			tau[tourOrder[i - 1]][tourOrder[i]] += delta_tau;
			tau[tourOrder[i]][tourOrder[i - 1]] += delta_tau;
		}
		tau[tourOrder[0]][tourOrder[0]] += delta_tau; //mark starting point
		tau[tourOrder[tourOrder.length - 1]][tourOrder[tourOrder.length - 1]] += delta_tau; //mark end point
	}

	/**
	 * ŏɖK₷ss肷
	 * @return ssԍ
	 */
	private int selectStartPoint() {
		int startPoint = 0;
		double sum = 0.0;
		double alpha = params.getAlpha();
		for(int i = 0; i < n_city; i++ ) {
			p[i] = Math.pow(tau[i][i], alpha);
			sum += p[i];
		}
		double value = sum * rand.nextDouble();
		sum = 0.0;
		for(int i = 0; i < n_city; i++ ) {
			sum += p[i];
			if(sum > value) {
				startPoint = i;
				break;
			}
		}
		return startPoint;
	}

	/**
	 * ŏɖK₷ss肷
	 * @return ssԍ
	 */
	private int selectStartPointRandomly() {
		int startPoint = 0;
		double sum = 0.0;
		for(int i = 0; i < n_city; i++ ) {
			p[i] = 1.0;
			sum += p[i];
		}
		double value = sum * rand.nextDouble();
		sum = 0.0;
		for(int i = 0; i < n_city; i++ ) {
			sum += p[i];
			if(sum > value) {
				startPoint = i;
				break;
			}
		}
		return startPoint;
	}

	/**
	 * K₷ss肷
	 * @return ssԍ
	 */
	private int selectNextStop() {
		int next_stop = 0;
		double sum = 0.0;
		double alpha = params.getAlpha();
		double beta = params.getBeta();
		for(int i = 0; i < n_city; i++ ) {
			p[i] = isNotVisited[i] * Math.pow(tau[currentCity][i], alpha)
			                       * Math.pow(eta[currentCity][i], beta);
			sum += p[i];
		}
		/*
		if(sum == 0.0) {
			System.out.println("SumIsZero cc:" + currentCity + " ");
			for(int i = 0; i < n_city; i++ ) {
				System.out.println(isNotVisited[i] + " " + tau[currentCity][i] + " " + eta[currentCity][i]);
			}
		}
		*/

		double value = sum * rand.nextDouble();
		sum = 0.0;
		for(int i = 0; i < n_city; i++ ) {
			sum += p[i];
			if(sum > value) {
				next_stop = i;
				break;
			}
		}
		return next_stop;
	}

	/**
	 * ɈړssAKss̒犮SɖׂɌ肷
	 * @return ssԍ
	 */
	private int selectNextStopRandomly() {
		int next_stop = 0;
		double sum = 0.0;
		for(int i = 0; i < n_city; i++ ) {
			p[i] = isNotVisited[i];
			sum += p[i];
		}
		double value = sum * rand.nextDouble();
		sum = 0.0;
		for(int i = 0; i < n_city; i++ ) {
			sum += p[i];
			if(sum > value) {
				next_stop = i;
				break;
			}
		}
		return next_stop;
	}
}
