/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap;

/**
 * @author iwata
 *
 */
public class GroupDivider {
	private double [][] mat;
	private double thresh;
	private boolean upper;
	private int [] groupingIndex;
	private int n_group;
	private int n_marker;

	public int [] getGroupingIndex(double [][] mat, double thresh, boolean upper) {
		this.mat = mat;
		this.thresh = thresh;
		this.upper = upper;
		n_marker = mat.length;
		groupingIndex = new int [n_marker];
		n_group = 0;

		int n_assigned_total = 0;
		do {
			int n_assigned = makeGroup();
			if(n_assigned == 0) {
				break; //Ô
			}
			n_assigned_total += n_assigned;
		} while(n_assigned_total < n_marker);

		return groupingIndex;
	}

	public int [] getGroupingIndexNNL(double [][] mat, double thresh, boolean upper) {
		this.mat = mat;
		this.thresh = thresh;
		this.upper = upper;
		n_marker = mat.length;
		groupingIndex = new int [n_marker];
		n_group = 0;

		int n_assigned_total = 0;
		do {
			int n_assigned = makeGroupNNL();
			if(n_assigned == 0) {
				break; //Ô
			}
			n_assigned_total += n_assigned;
		} while(n_assigned_total < n_marker);

		return groupingIndex;
	}

	private int makeGroup() {
		int group_size = 0;
		int start = 0;

		for(int i = 0; i < n_marker; i++ ) {
			if(groupingIndex[i] == 0) {
				n_group ++;
				groupingIndex[i] = n_group;
				group_size ++;
				start = i + 1;
				break;
			}
		}

		if(group_size != 0) {
			int last_size;
			do {
				last_size = group_size;
				for(int i = start; i < n_marker; i++ ) {
					if(groupingIndex[i] == 0) {
						for(int j = 0; j < n_marker; j++ ) {
							if(upper) {
								if(groupingIndex[j] == n_group && mat[i][j] <= thresh) {
									groupingIndex[i] = n_group;
									group_size ++;
									break;
								}
							} else {
								if(groupingIndex[j] == n_group && mat[i][j] >= thresh) {
									groupingIndex[i] = n_group;
									group_size ++;
									break;
								}
							}
						}
						//System.out.println();
						//System.out.println(n_group + " " + last_size + " " +group_size + " " + thresh);
					}
				}
			} while(group_size != last_size);
		}

		return group_size;
	}

	private int makeGroupNNL() {
		int group_size = 0;
		int start = 0;
		int left = 0;
		int right = 0;

		for(int i = 0; i < n_marker; i++ ) {
			if(groupingIndex[i] == 0) {
				n_group ++;
				groupingIndex[i] = n_group;
				group_size ++;
				start = i + 1;
				left = i;
				right = i;
				//System.out.print(left);
				break;
			}
		}

		if(group_size != 0) {
			if(upper) {
				while(true) {
					double min = Double.MAX_VALUE;
					int min_index = 0;
					for(int i = start; i < n_marker; i++ ) {
						if(groupingIndex[i] == 0 && mat[left][i] < min) {
							min = mat[left][i];
							min_index = i;
						}
					}
					if(min < thresh) {
						groupingIndex[min_index] = n_group;
						left = min_index;
						//System.out.print(" " + left);
					} else {
						break;
					}
				}

				while(true) {
					double min = Double.MAX_VALUE;
					int min_index = 0;
					for(int i = start; i < n_marker; i++ ) {
						if(groupingIndex[i] == 0 && mat[right][i] < min) {
							min = mat[right][i];
							min_index = i;
						}
					}
					if(min < thresh) {
						groupingIndex[min_index] = n_group;
						right = min_index;
						//System.out.print("-" + right);
					} else {
						break;
					}
				}
			} else {
				while(true) {
					double max = Double.MIN_VALUE;
					int max_index = 0;
					for(int i = start; i < n_marker; i++ ) {
						if(groupingIndex[i] == 0 && mat[left][i] > max) {
							max = mat[left][i];
							max_index = i;
						}
					}
					if(max > thresh) {
						groupingIndex[max_index] = n_group;
						left = max_index;
						//System.out.print(" " + left);
					} else {
						break;
					}
				}

				while(true) {
					double max = Double.MIN_VALUE;
					int max_index = 0;
					for(int i = start; i < n_marker; i++ ) {
						if(groupingIndex[i] == 0 && mat[right][i] > max) {
							max = mat[right][i];
							max_index = i;
						}
					}
					if(max > thresh) {
						groupingIndex[max_index] = n_group;
						right = max_index;
						//System.out.print("-" + right);
					} else {
						break;
					}
				}
			}

		}

		return group_size;

	}

}
