/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap;

import java.util.ArrayList;

/**
 * @author iwata
 *
 */
public class GroupExtractor {
	ArrayList groupList = new ArrayList();

	public GroupExtractor (int [] groupingIndex) {
		storeData(groupingIndex, 3);
	}

	public GroupExtractor (int [] groupingIndex, int n_min) {
		storeData(groupingIndex, n_min);
	}

	private void storeData(int [] groupingIndex, int n_min) {
		int maxIndex = getMaxIndex(groupingIndex);
		//groupList = new ArrayList(maxIndex);
		for(int i = 0; i <= maxIndex; i++ ) {
			ArrayList markerList = new ArrayList(groupingIndex.length);
			for(int j = 0; j < groupingIndex.length; j++ )
				if(groupingIndex[j] == i)
					markerList.add(new Integer(j));
			if(markerList.size() >= n_min)
				groupList.add(markerList);
		}

	}

	private int getMaxIndex(int [] groupingIndex) {
		int maxIndex = 0;
		for(int i = 0; i < groupingIndex.length; i++ )
			if(groupingIndex[i] > maxIndex)
				maxIndex = groupingIndex[i];
		return maxIndex;
	}

	public int getN_group() {
		return groupList.size();
	}

	public int getN_marker(int n) {
		if(n >= groupList.size())
			return 0;
		return ((ArrayList) groupList.get(n)).size();
	}

	public int [] getMarkerIndices(int n) {
		if(n >= groupList.size())
			return null;
		ArrayList al = (ArrayList) groupList.get(n);
		return convertArrayListToIntArray(al);
	}

	private int [] convertArrayListToIntArray(ArrayList al) {
		int [] ia = new int [al.size()];
		for(int i = 0; i < ia.length; i++ )
			ia[i] = ((Integer)al.get(i)).intValue();
		return ia;
	}

	private String [] convertArrayListToStrings(ArrayList ls) {
		String [] ss = new String [ls.size()];
		for(int i = 0; i < ls.size(); i++ ) {
			ss[i] = ls.get(i).toString();
		}
		return ss;
	}

}
