/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap;

/**
 * @author iwata
 *
 */
public class LeqDMatrixFactory {
	public double [][] convertR2LeqD(double [][] r) {
		double [][] leqD = new double[r.length][r[0].length];
		for(int i = 0; i < r.length; i++ ) {
			leqD[i][i] = 0.0;
			for(int j = i + 1; j < r[0].length; j++ ) {
				if(r[i][j] >= 0.5)
					leqD[i][j] = - Math.log(0.5);
				else if(r[i][j] <= 0.0)
					leqD[i][j] = 0.0;
				else
					leqD[i][j] = - r[i][j] * Math.log(r[i][j]) - (1 - r[i][j]) * Math.log(1 - r[i][j]);
				leqD[j][i] = leqD[i][j];
			}
		}
		return leqD;
	}
}
