/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap;

import org.agmodel.bioinfo.segregation.MapFunction;
import java.util.Arrays;

/**
 * @author iwata
 *
 */
public class MapData {
	private MarkerBean [] marker;
	private MapFunction mf = new MapFunction();
	private String name;

	public MapData() {
		init();
	}

	public MapData(int mapFunction) {
		setMapFunction(mapFunction);
		init();
	}

	private void init() {
		marker = new MarkerBean [1];
		marker[0] = new MarkerBean();
		name = "NA";
	}

	public MapData(int [] markerIndex, int [] bestOrder, String [] name, double [][] r) {
		setMarkers(markerIndex, bestOrder, name, r);
		/*
		marker = new MarkerBean [markerIndex.length];
		int [] orderedIndex = new IndexConverter().getOrderedIndex(markerIndex, bestOrder);
		double location = 0;
		for(int i = 0; i < marker.length; i++ ) {
			marker[i] = new MarkerBean();
			marker[i].setIndex(orderedIndex[i]);
			marker[i].setName(name[bestOrder[i]]);
			if(i > 0)
				location += mf.getDistance(r[bestOrder[i]][bestOrder[i - 1]]) * 100;
			marker[i].setLocation(location);
		}
		*/
	}

	public void setMarkers(int [] markerIndex, int [] bestOrder, String [] name, double [][] r) {
		marker = null;
		marker = new MarkerBean [markerIndex.length];
		int [] orderedIndex = new IndexConverter().getOrderedIndex(markerIndex, bestOrder);
		double location = 0;
		for(int i = 0; i < marker.length; i++ ) {
			marker[i] = new MarkerBean();
			marker[i].setIndex(orderedIndex[i]);
			marker[i].setName(name[bestOrder[i]]);
			if(i > 0)
				location += mf.getDistance(r[bestOrder[i]][bestOrder[i - 1]]) * 100;
			marker[i].setLocation(location);
		}
		alignMarkers();
	}

	public void alignMarkers() {
		Arrays.sort(marker);
	}

	public int getNMarker() {
		return marker.length;
	}

	public double getLength() {
		return marker[marker.length - 1].getLocation();
	}

	public MarkerBean getMarker(int i) {
		if(i < marker.length)
			return marker[i];
		return new MarkerBean();
	}

	public int [] getMarkerIndexArray() {
		int [] index = new int [marker.length];
		for(int i = 0; i < marker.length; i++ )
			index[i] = marker[i].getIndex();
		return index;
	}

	public int getMarkerIndex(int i) {
		if(i < marker.length)
			return marker[i].getIndex();
		return 0;
	}

	public String getMarkerName(int i) {
		if(i < marker.length)
			return marker[i].getName();
		return "NA";
	}

	public double getMarkerLocation(int i) {
		if(i < marker.length)
			return marker[i].getLocation();
		return 0.0;
	}

	public double getMarkerBootProb(int i) {
		if(i < marker.length)
			return marker[i].getBootProb();
		return 0.0;
	}

	public boolean setMarkerBootProb(int i, double bootProb) {
		if(i < marker.length) {
			marker[i].setBootProb(bootProb);
			return true;
		}
		return false;
	}

	/**
	 * @return
	 */
	public int getMapFunction() {
		return mf.getFunction();
	}

	/**
	 * @param b
	 */
	public void setMapFunction(int i) {
		mf.setFunction(i);
	}

	public void show() {
		for(int i = 0; i < marker.length; i++ ) {
			System.out.print("\t" + marker[i].getIndex());
			System.out.print("\t" + marker[i].getName());
			System.out.print("\t" + marker[i].getLocation());
			System.out.println("\t" + marker[i].getBootProb());
		}
	}

	public void showLocation() {
		for(int i = 0; i < marker.length; i++ ) {
			System.out.print("\t" + marker[i].getIndex());
			System.out.print("\t" + marker[i].getName());
			System.out.println("\t" + marker[i].getLocation());
		}
	}

	public void showBootProb() {
		for(int i = 0; i < marker.length; i++ ) {
			System.out.print("\t" + marker[i].getIndex());
			System.out.print("\t" + marker[i].getName());
			System.out.println("\t" + marker[i].getBootProb());
		}
	}

	/**
	 * @return
	 */
	public String getName() {
		return name;
	}

	/**
	 * @param string
	 */
	public void setName(String string) {
		name = string;
	}

}
