/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap;

/**
 * @author iwata
 *
 */
public class MarkerBean implements java.io.Serializable, Comparable {
	private int index;
	private String Name;
	private double location;
	private double bootProb;

	public MarkerBean() {
		index = 0;
		Name = "NA";
		location = 0.0;
		bootProb = 0.0;
	}

	/**
	 * @return
	 */
	public double getBootProb() {
		return bootProb;
	}

	/**
	 * @return
	 */
	public int getIndex() {
		return index;
	}

	/**
	 * @return
	 */
	public double getLocation() {
		return location;
	}

	/**
	 * @return
	 */
	public String getName() {
		return Name;
	}

	/**
	 * @param d
	 */
	public void setBootProb(double d) {
		bootProb = d;
	}

	/**
	 * @param i
	 */
	public void setIndex(int i) {
		index = i;
	}

	/**
	 * @param d
	 */
	public void setLocation(double d) {
		location = d;
	}

	/**
	 * @param string
	 */
	public void setName(String string) {
		Name = string;
	}

	public int compareTo(Object object) {
		return compareTo((MarkerBean)object);
	}

	public int compareTo(MarkerBean mb) {
		if(location < mb.getLocation())
			return -1;
		else if(location > mb.getLocation())
			return 1;
		else //location == mb.getLocation()
			if(index < mb.getIndex())
				return -1;
			else if(index > mb.getIndex())
				return 1;
			else //index == mb.getIndex()
				return 0;
	}

}
