/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap;

/**
 * @author iwata
 *
 */
public class NMatrixFactory {
	public int [][] getN(SegDataBean segDataBean) {
		int [][] n = new int [1][1];
		char [][] genotypeData = segDataBean.getGenotypeData();
		n = convertSegData2N(genotypeData);
		return n;
	}

	public int [][] getN(SegDataBean segDataBean, int [] markerIndex) {
		int [][] n = new int [1][1];
		char [][] genotypeData = new PartialExtractor().extractPartialGenotypeData(segDataBean.getGenotypeData(), markerIndex);
		n = convertSegData2N(genotypeData);
		return n;
	}

	private int [][] convertSegData2N(char [][] genotypeData) {
		int nMarker = genotypeData.length;
		int nProgeny = genotypeData[0].length;
		int [][] n = new int [nMarker][nMarker];
		for(int i = 0; i < nMarker; i++)
			for(int j = 0; j < nMarker; j++)
				for(int k = 0; k < nProgeny; k++)
					if(genotypeData[i][k] != '-' && genotypeData[j][k] != '-')
						n[i][j] ++;
		return n;
	}
}
