/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap;

import org.agmodel.bioinfo.segregation.MapFunction;

/**
 * @author iwata
 *
 */
public class OrderingOptionBean implements java.io.Serializable {
	private int maxIteration = 20;
	private int nConfirm = 2;
	private int mapFunction = MapFunction.MF_HALDANE;
	private int criterion = OrderingCriterion.OC_LL;
	private int nBootstrap = 100;
	private int groupIndex = -1; //-1 is all

	public OrderingOptionBean() {

	}
	/**
	 * @return
	 */
	public int getGroupIndex() {
		return groupIndex;
	}

	/**
	 * @return
	 */
	public int getMapFunction() {
		return mapFunction;
	}

	/**
	 * @return
	 */
	public int getCriterion() {
		return criterion;
	}

	/**
	 * @return
	 */
	public int getMaxIteration() {
		return maxIteration;
	}

	/**
	 * @return
	 */
	public int getNConfirm() {
		return nConfirm;
	}

	/**
	 * @param i
	 */
	public void setGroupIndex(int i) {
		groupIndex = i;
	}

	/**
	 * @param i
	 */
	public void setMapFunction(int i) {
		mapFunction = i;
	}

	/**
	 * @param i
	 */
	public void setCriterion(int i) {
		criterion = i;
	}

	/**
	 * @param i
	 */
	public void setMaxIteration(int i) {
		maxIteration = i;
	}

	/**
	 * @param i
	 */
	public void setNConfirm(int i) {
		nConfirm = i;
	}

	/**
	 * @return
	 */
	public int getNBootstrap() {
		return nBootstrap;
	}

	/**
	 * @param i
	 */
	public void setNBootstrap(int i) {
		nBootstrap = i;
	}

}
