/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap;

/**
 * @author iwata
 *
 * ̐ꂽRg̑}ev[gύX邽
 * EBhE > ݒ > Java > R[h > R[hƃRg
 */
public class SegDataBean implements java.io.Serializable {
	private String fileName;
	private char [][] genotypeData; //segregation data
	private int segType; //segregation type
	private String [] markerName;
	private int [] markerType;

	/**
	 * Ȃ̃RXgN^
	 *
	 */
	public SegDataBean() {
		fileName = "NA";
		genotypeData = new char[1][1];
		segType = -1;
		markerName = new String [1];
		markerName[0] = "Marker0";
		markerType = new int[1];
	}

	/**
	 * ̃RXgN^
	 * @param segData f[^icɃ}[J[AɌ́j. MapMakerɏ
	 * @param segType ^CviF2=0, BC=1, RIL=2, DH=2 or NA=-1(not available))
	 */
	public SegDataBean(int segType, String [] markerName, char [][] genotypeData) {
		this.genotypeData = genotypeData;
		this.segType = segType;
		this.markerName = markerName;
	}

	/**
	 * ̃RXgN^
	 * @param segData f[^icɃ}[J[AɌ́j. MapMakerɏ
	 * @param segType ^CviF2=0, BC=1, RIL=2, DH=2 or NA=-1(not available))
	 */
	public SegDataBean(String fileName, int segType, String [] markerName, char [][] genotypeData) {
		this.fileName = fileName;
		this.genotypeData = genotypeData;
		this.segType = segType;
		this.markerName = markerName;
	}

	/**
	 * get the number of individuals
	 * @return
	 */
	public int getN_individual() {
		return genotypeData[0].length;
	}

	/**
	 * get the number of markers
	 * @return
	 */
	public int getN_marker() {
		return genotypeData.length;
	}

	/**
	 * get segregation data
	 * @return
	 */
	public char [][] getGenotypeData() {
		return genotypeData;
	}

	/**
	 * get segregation type
	 * @return
	 */
	public int getSegType() {
		return segType;
	}

	/**
	 * set segregation data
	 * @param is
	 */
	public void setGenotypeData(char [][] is) {
		genotypeData = is;
	}

	/**
	 * set segregation type
	 * @param string
	 */
	public void setSegType(int i) {
		segType = i;
	}

	/**
	 * @return
	 */
	public String[] getMarkerName() {
		return markerName;
	}

	/**
	 * @param strings
	 */
	public void setMarkerName(String[] strings) {
		markerName = strings;
	}

	/**
	 * @return
	 */
	public int[] getMarkerType() {
		return markerType;
	}

	/**
	 * @param is
	 */
	public void setMarkerType(int[] is) {
		markerType = is;
	}

	/**
	 * @return
	 */
	public String getFileName() {
		return fileName;
	}

	/**
	 * @param string
	 */
	public void setFileName(String string) {
		fileName = string;
	}

}
