/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap;

import java.util.ArrayList;
import org.agmodel.bioinfo.segregation.*;

/**
 * @author iwata
 * Verify segregation data bean
 */
public class SegDataVerifier {
	public String [] verify(SegDataBean segDataBean) {
		ArrayList message = new ArrayList();
		char [][] gtData = segDataBean.getGenotypeData();
		String [] markerName = segDataBean.getMarkerName();
		if(segDataBean.getSegType() == SegType.ST_F2) {
			int [] markerType = segDataBean.getMarkerType();
			for(int i = 0; i < gtData.length; i++ ) {
				if(markerType[i] == MarkerType.MT_CODOM) {
					for(int j = 0; j < gtData[0].length; j++) {
						if(!(gtData[i][j] == 'A' || gtData[i][j] == 'B' || gtData[i][j] == 'H'
						     || gtData[i][j] ==  '-')) {
							message.add("Progeny " + (j + 1) + " has a wrong code '" + gtData[i][j] + "' at " + markerName[i]);
						}
					}
				} else if(markerType[i] == MarkerType.MT_DOM_P1) {
					for(int j = 0; j < gtData[0].length; j++) {
						if(!(gtData[i][j] == 'D' || gtData[i][j] == 'B'
							 || gtData[i][j] ==  '-')) {
							message.add("Progeny " + (j + 1) + " has a wrong code '" + gtData[i][j] + "' at " + markerName[i]);
						}
					}
				} else if(markerType[i] == MarkerType.MT_DOM_P2) {
					for(int j = 0; j < gtData[0].length; j++) {
						if(!(gtData[i][j] == 'A' || gtData[i][j] == 'C'
							 || gtData[i][j] ==  '-')) {
							message.add("Progeny " + (j + 1) + " has a wrong code '" + gtData[i][j] + "' at " + markerName[i]);
						}
					}
				}
			}
		} else if(segDataBean.getSegType() == SegType.ST_BC) {
			for(int i = 0; i < gtData.length; i++ ) {
				for(int j = 0; j < gtData[0].length; j++ ) {
					if(!(gtData[i][j] == 'A' || gtData[i][j] == 'H' || gtData[i][j] == '-')) {
						message.add("Progeny " + (j + 1) + "has a wrong code '" + gtData[i][j] + "' at " + markerName[i]);
					}
				}
			}
		} else if(segDataBean.getSegType() == SegType.ST_RIL || segDataBean.getSegType() == SegType.ST_DH) {
			for(int i = 0; i < gtData.length; i++ ) {
				for(int j = 0; j < gtData[0].length; j++ ) {
					if(!(gtData[i][j] == 'A' || gtData[i][j] == 'B' || gtData[i][j] == '-')) {
						message.add("Progeny " + (j + 1) + "has a wrong code '" + gtData[i][j] + "' at " + markerName[i]);
					}
				}
			}
		} else {
			message.add("Unknown segregation type");
		}

		return convertArrayListToStrings(message);
	}

	private String [] convertArrayListToStrings(ArrayList ls) {
		String [] ss = new String [ls.size()];
		for(int i = 0; i < ls.size(); i++ ) {
			ss[i] = ls.get(i).toString();
		}
		return ss;
	}

}
