/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap;

import org.agmodel.bioinfo.segregation.SegRatioTest;
import org.agmodel.bioinfo.segregation.SegRatioBean;
import java.text.DecimalFormat;
import org.agmodel.bioinfo.common.StringFormat;

/**
 * @author iwata
 *
 */
public class SegRatioTester {

	public String [] testAllLoci(SegDataBean segDataBean) {
		int n_marker = segDataBean.getN_marker();
		String [] message = new String [n_marker];
		int segType = segDataBean.getSegType();
		char [][] genotypeData = segDataBean.getGenotypeData();
		String [] markerName = segDataBean.getMarkerName();
		SegRatioTest segRatioTest = new SegRatioTest();
		DecimalFormat decimalFormat1 = new DecimalFormat("###,###,##0.00");
		DecimalFormat decimalFormat2 = new DecimalFormat("0.0000");
		StringFormat stringFormat = new StringFormat();
		for(int i = 0; i < n_marker; i++ ) {
			SegRatioBean segRatioBean = segRatioTest.test(segType, genotypeData[i]);
			message[i] = stringFormat.format(markerName[i], 10, true)
						+ " " + stringFormat.format(new Integer(segRatioBean.getN_valid()).toString(), 3, false)
						+ " " + stringFormat.format(segRatioBean.getObsRatio(), 11, false)
						+ " " + stringFormat.format(decimalFormat1.format(segRatioBean.getChiSqr()), 8, false)
					    + " " + stringFormat.format(decimalFormat2.format(segRatioBean.getP()), 8, false)
						+ " " + segRatioBean.getSigStars();

		}

		return message;
	}

}
