/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap.gui;

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;
import org.agmodel.bioinfo.antmap.*;

/**
 * JPanel for setting ACO parameters
 * <p>Title: AntMap</p>
 * <p>Explanation: Linkage mapping software based on ACO algorithm</p>
 * <p>Copyright: Copyright (c) 2004 NARO</p>
 * <p>Company name: NARO</p>
 * @author Hiroyoshi IWATA
 * @version 1.1
 */
public class AcoParamsPanel extends JPanel {
  private AcoParamsBean acoParamsBean = new AcoParamsBean();

  DblParamPanel dppAlpha = new DblParamPanel();
  DblParamPanel dppBeta = new DblParamPanel();
  DblParamPanel dppRho = new DblParamPanel();
  DblParamPanel dppQ = new DblParamPanel();
  IntParamPanel ippNIteration = new IntParamPanel();
  IntParamPanel ippNAnt = new IntParamPanel();
  DblParamPanel dppInitTau = new DblParamPanel();
  DblParamPanel dppPFancy = new DblParamPanel();
  DblParamPanel dppWeight = new DblParamPanel();

  GridLayout gridLayout1 = new GridLayout();
  JPanel jPanel1 = new JPanel();
  JButton jButtonLoad = new JButton();
  JButton jButtonSave = new JButton();
  JFileChooser jFileChooser1 = new JFileChooser();

  public AcoParamsPanel() {
    try {
      jbInit();
    }
    catch(Exception e) {
      e.printStackTrace();
    }
  }

  private void jbInit() throws Exception {
    dppAlpha.setText("Alpha: ");
    dppAlpha.setValue(acoParamsBean.getAlpha());
    dppAlpha.setRange(DblParamPanel.VR_POSITIVE_AND_ZERO);
    dppBeta.setText("Beta: ");
    dppBeta.setValue(acoParamsBean.getBeta());
    dppBeta.setRange(DblParamPanel.VR_POSITIVE_AND_ZERO);
    dppRho.setText("Rho: ");
    dppRho.setValue(acoParamsBean.getRho());
    dppRho.setRange(DblParamPanel.VR_POSITIVE);
    dppQ.setText("Q: ");
    dppQ.setValue(acoParamsBean.getQ());
    dppQ.setRange(DblParamPanel.VR_POSITIVE);
    ippNIteration.setText("# iterations: ");
    ippNIteration.setValue(acoParamsBean.getN_iteration());
    ippNIteration.setRange(IntParamPanel.VR_POSITIVE);
    ippNAnt.setText("# ants: ");
    ippNAnt.setValue(acoParamsBean.getN_ant());
    ippNAnt.setRange(IntParamPanel.VR_POSITIVE);
    dppInitTau.setText("Initial value of tau: ");
    dppInitTau.setValue(acoParamsBean.getInit_tau());
    dppInitTau.setRange(DblParamPanel.VR_POSITIVE);
    dppPFancy.setText("Probability of fanciful choice: ");
    dppPFancy.setValue(acoParamsBean.getP_fancy());
    dppPFancy.setRange(DblParamPanel.VR_POSITIVE_AND_ZERO);
    dppWeight.setText("Weight for the best tour: ");
    dppWeight.setValue(acoParamsBean.getWeight());
    dppWeight.setRange(DblParamPanel.VR_POSITIVE_AND_ZERO);

    this.setLayout(gridLayout1);
    gridLayout1.setColumns(1);
    gridLayout1.setRows(10);
    jButtonLoad.setText("Load parameters");
    jButtonLoad.addActionListener(new ACOOptionPanel_jButtonLoad_actionAdapter(this));
    jButtonSave.setText("Save parameters");
    jButtonSave.addActionListener(new ACOOptionPanel_jButtonSave_actionAdapter(this));
    this.add(dppAlpha, null);
    this.add(dppBeta, null);
    this.add(dppRho, null);
    this.add(dppQ, null);
    this.add(ippNIteration, null);
    this.add(ippNAnt, null);
    this.add(dppInitTau, null);
    this.add(dppPFancy, null);
    this.add(dppWeight, null);
    this.add(jPanel1, null);
    jPanel1.add(jButtonLoad, null);
    jPanel1.add(jButtonSave, null);
  }

  void jButtonLoad_actionPerformed(ActionEvent e) {
    jFileChooser1.setDialogTitle("Open parameter file");
    if(jFileChooser1.showOpenDialog(this) == JFileChooser.APPROVE_OPTION) {
      String fileName = jFileChooser1.getSelectedFile().getPath();
      try {
        acoParamsBean = new AcoParamsReader().loadAcoParamsBean(fileName);
        updateValue();
      } catch (Exception ex) {
        JOptionPane.showMessageDialog(this, ex.getMessage(), "File Error", JOptionPane.ERROR_MESSAGE);
      }
    }
  }

  public void setAcoParamsBean(AcoParamsBean acoParamsBean) {
    this.acoParamsBean = acoParamsBean;
    updateValue();
  }

  private void updateValue() {
    dppAlpha.setValue(acoParamsBean.getAlpha());
    dppBeta.setValue(acoParamsBean.getBeta());
    dppRho.setValue(acoParamsBean.getRho());
    dppQ.setValue(acoParamsBean.getQ());
    ippNIteration.setValue(acoParamsBean.getN_iteration());
    ippNAnt.setValue(acoParamsBean.getN_ant());
    dppInitTau.setValue(acoParamsBean.getInit_tau());
    dppPFancy.setValue(acoParamsBean.getP_fancy());
    dppWeight.setValue(acoParamsBean.getWeight());
  }

  public AcoParamsBean getAcoParamsBean() {
    acoParamsBean.setAlpha(dppAlpha.getValue());
    acoParamsBean.setBeta(dppBeta.getValue());
    acoParamsBean.setRho(dppRho.getValue());
    acoParamsBean.setQ(dppQ.getValue());
    acoParamsBean.setN_iteration(ippNIteration.getValue());
    acoParamsBean.setN_ant(ippNAnt.getValue());
    acoParamsBean.setInit_tau(dppInitTau.getValue());
    acoParamsBean.setP_fancy(dppPFancy.getValue());
    acoParamsBean.setWeight(dppWeight.getValue());
    return acoParamsBean;
  }

  void jButtonSave_actionPerformed(ActionEvent e) {
    jFileChooser1.setDialogTitle("Save parameter file");
    if(jFileChooser1.showSaveDialog(this) == JFileChooser.APPROVE_OPTION) {
      String fileName = jFileChooser1.getSelectedFile().getPath();
      try {
        new AcoParamsWriter().saveAcoParamsBean(fileName, getAcoParamsBean());
      } catch (Exception ex) {
        JOptionPane.showMessageDialog(this, ex.getMessage(), "File Error", JOptionPane.ERROR_MESSAGE);
      }
    }
  }

}

class ACOOptionPanel_jButtonLoad_actionAdapter implements java.awt.event.ActionListener {
  AcoParamsPanel adaptee;

  ACOOptionPanel_jButtonLoad_actionAdapter(AcoParamsPanel adaptee) {
    this.adaptee = adaptee;
  }
  public void actionPerformed(ActionEvent e) {
    adaptee.jButtonLoad_actionPerformed(e);
  }
}

class ACOOptionPanel_jButtonSave_actionAdapter implements java.awt.event.ActionListener {
  AcoParamsPanel adaptee;

  ACOOptionPanel_jButtonSave_actionAdapter(AcoParamsPanel adaptee) {
    this.adaptee = adaptee;
  }
  public void actionPerformed(ActionEvent e) {
    adaptee.jButtonSave_actionPerformed(e);
  }
}
