/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap.gui;

import javax.swing.JTabbedPane;
import org.agmodel.bioinfo.antmap.*;

/**
 * Panel for setting options of AntMap
 * <p>Title: AntMap</p>
 * <p>Explanation: Linkage mapping software based on ACO algorithm</p>
 * <p>Copyright: Copyright (c) 2004 NARO</p>
 * <p>Company name: NARO</p>
 * @author Hiroyoshi IWATA
 * @version 1.1
 */
public class AntMapOptionPanel extends JTabbedPane {
  GroupingOptionPanel groupingOptionPanel = new GroupingOptionPanel();
  OrderingOptionPanel orderingOptionPanel = new OrderingOptionPanel();
  AcoParamsPanel acoParamsPanel = new AcoParamsPanel();
  DrawMapOptionPanel drawMapOptionPanel = new DrawMapOptionPanel();


  public AntMapOptionPanel() {
    this.add(groupingOptionPanel, "Grouping");
    this.add(orderingOptionPanel, "Ordering");
    this.add(acoParamsPanel, "Ant Colony Optimization");
    this.add(drawMapOptionPanel, "Draw map");
  }

  public GroupingOptionBean getGroupingOptionBean() {
    return groupingOptionPanel.getGroupingOptionBean();
  }

  public void setGroupingOptionBean(GroupingOptionBean groupingOptionBean) {
    groupingOptionPanel.setGroupingOptionBean(groupingOptionBean);
  }

  public OrderingOptionBean getOrderingOptionBean() {
    return orderingOptionPanel.getOrderingOptionBean();
  }

  public void setOrderingOptionBean(OrderingOptionBean orderingOptionBean) {
    orderingOptionPanel.setOrderingOptionBean(orderingOptionBean);
  }

  public void setOrderingGroupNames(String [] groupName) {
    orderingOptionPanel.setGroupNames(groupName);
  }

  public AcoParamsBean getAcoParamsBean() {
    return acoParamsPanel.getAcoParamsBean();
  }

  public void setAcoParamsBean(AcoParamsBean acoParamsBean) {
    acoParamsPanel.setAcoParamsBean(acoParamsBean);
  }

  public DrawMapOptionBean getDrawMapOptionBean() {
    return drawMapOptionPanel.getDrawMapOptionBean();
  }

  public void setDrawMapOptionBean(DrawMapOptionBean drawMapOptionBean) {
    drawMapOptionPanel.setDrawMapOptionBean(drawMapOptionBean);
  }
}
