/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap.gui;

import java.awt.*;
import javax.swing.*;

/**
 * Panel with jComboBox
 * <p>Title: AntMap</p>
 * <p>Explanation: Linkage mapping software based on ACO algorithm</p>
 * <p>Copyright: Copyright (c) 2004 NARO</p>
 * <p>Company name: NARO</p>
 * @author Hiroyoshi IWATA
 * @version 1.1
 */
public class ComboBoxPanel extends JPanel {
  private String text = "NA";

  JLabel jLabel1 = new JLabel();
  FlowLayout flowLayout1 = new FlowLayout();
  JComboBox jComboBox1 = new JComboBox();

  public ComboBoxPanel() {
    try {
      jbInit();
    }
    catch(Exception ex) {
      ex.printStackTrace();
    }
  }

  public ComboBoxPanel(String text) {
    this.text = text;
    try {
      jbInit();
    }
    catch(Exception ex) {
      ex.printStackTrace();
    }
  }

  public ComboBoxPanel(String text, Object [] itemArray) {
    this.text = text;
    try {
      jbInit();
      addItems(itemArray);
    }
    catch(Exception ex) {
      ex.printStackTrace();
    }
  }

  public String getText() {
    return text;
  }

  public void setText(String text) {
    this.text = text;
    jLabel1.setText(text);
  }

  public void addItem(Object item) {
    jComboBox1.addItem(item);
  }

  public void addItems(Object [] itemArray) {
    for(int i = 0; i < itemArray.length; i++)
      jComboBox1.addItem(itemArray[i]);
  }

  public void removeAllItems() {
    jComboBox1.removeAllItems();
  }

  public void removeItemAt(int i) {
    jComboBox1.removeItemAt(i);
  }

  public void setSelectedIndex(int i) {
    jComboBox1.setSelectedIndex(i);
  }

  public int getSelectedIndex() {
    return jComboBox1.getSelectedIndex();
  }

  public void setSelectedItem(Object item) {
    jComboBox1.setSelectedItem(item);
  }

  public Object getSelectedItem() {
    return jComboBox1.getSelectedItem();
  }

  void jbInit() throws Exception {
    jLabel1.setText(text);
    this.setLayout(flowLayout1);
    this.add(jLabel1, null);
    this.add(jComboBox1, null);
  }
}
