/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap.gui;

import java.awt.Font;

/**
 * <p>^Cg: </p>
 * <p>: </p>
 * <p>쌠: Copyright (c) 2004</p>
 * <p>Ж: </p>
 * @author 
 * @version 1.0
 */

/**
 * Bean for containing values of options for a linkage map drawing
 * <p>Title: AntMap</p>
 * <p>Explanation: Linkage mapping software based on ACO algorithm</p>
 * <p>Copyright: Copyright (c) 2004 NARO</p>
 * <p>Company name: NARO</p>
 * @author Hiroyoshi IWATA
 * @version 1.1
 */
public class DrawMapOptionBean {
  private double scaleFactor = 4.0;
  private int mapSpacing = 20;
  private int marginSize = 20;
  private boolean showBootstrapValue = false;
  private Font fontGroupName = new Font("Default", Font.BOLD, 14);
  private Font fontMarkerInfo = new Font("Default", Font.PLAIN, 12);

  public DrawMapOptionBean() {
  }

  /**
   * @return
   */
  public Font getFontGroupName() {
          return fontGroupName;
  }

  /**
   * @return
   */
  public Font getFontMarkerInfo() {
          return fontMarkerInfo;
  }

  /**
   * @return
   */
  public int getMapSpacing() {
          return mapSpacing;
  }

  /**
   * @return
   */
  public int getMarginSize() {
          return marginSize;
  }

  /**
   * @return
   */
  public double getScaleFactor() {
          return scaleFactor;
  }

  /**
   * @return
   */
  public boolean isShowBootstrapValue() {
          return showBootstrapValue;
  }

  /**
   * @param font
   */
  public void setFontGroupName(Font font) {
          fontGroupName = font;
  }

  /**
   * @param font
   */
  public void setFontMarkerInfo(Font font) {
          fontMarkerInfo = font;
  }

  /**
   * @param i
   */
  public void setMapSpacing(int i) {
          mapSpacing = i;
  }

  /**
   * @param i
   */
  public void setMarginSize(int i) {
          marginSize = i;
  }

  /**
   * @param d
   */
  public void setScaleFactor(double d) {
          scaleFactor = d;
  }

  /**
   * @param b
   */
  public void setShowBootstrapValue(boolean b) {
          showBootstrapValue = b;
  }



}
