/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap.gui;

import java.awt.*;
import javax.swing.*;
import javax.swing.border.*;
import java.awt.event.*;

/**
 * <p>^Cg: </p>
 * <p>: </p>
 * <p>쌠: Copyright (c) 2004</p>
 * <p>Ж: </p>
 * @author 
 * @version 1.0
 */

public class DrawMapOptionPanel extends JPanel {
  private DrawMapOptionBean drawMapOptionBean = new DrawMapOptionBean();

  GridLayout gridLayout1 = new GridLayout();
  RadioButtonPanel rbpBootstrapProb = new RadioButtonPanel();
  DblParamPanel dppScaleFactor = new DblParamPanel();
  IntParamPanel ippMapSpacing = new IntParamPanel();
  IntParamPanel ippMarginSize = new IntParamPanel();
  FontChooserPanel fcpGroupName = new FontChooserPanel();
  FontChooserPanel fcpMarkerInfo = new FontChooserPanel();

  public DrawMapOptionPanel() {
    try {
      jbInit();
    }
    catch(Exception ex) {
      ex.printStackTrace();
    }
  }

  public DrawMapOptionBean getDrawMapOptionBean() {
    drawMapOptionBean.setScaleFactor(dppScaleFactor.getValue());
    drawMapOptionBean.setMapSpacing(ippMapSpacing.getValue());
    drawMapOptionBean.setMarginSize(ippMarginSize.getValue());
    drawMapOptionBean.setShowBootstrapValue(isShowBootstrapValue());
    drawMapOptionBean.setFontGroupName(fcpGroupName.getSelectedFont());
    drawMapOptionBean.setFontMarkerInfo(fcpMarkerInfo.getSelectedFont());
    return drawMapOptionBean;
  }

  public void setDrawMapOptionBean(DrawMapOptionBean drawMapOptionBean) {
    this.drawMapOptionBean = drawMapOptionBean;
    dppScaleFactor.setValue(this.drawMapOptionBean.getScaleFactor());
    ippMapSpacing.setValue(this.drawMapOptionBean.getMapSpacing());
    ippMarginSize.setValue(this.drawMapOptionBean.getMarginSize());
    setShowBootstrapValue(this.drawMapOptionBean.isShowBootstrapValue());
    fcpGroupName.setSelectedFont(this.drawMapOptionBean.getFontGroupName());
    fcpMarkerInfo.setSelectedFont(this.drawMapOptionBean.getFontMarkerInfo());
  }

  public void setShowBootstrapValue(boolean b) {
    if(b == true)
      rbpBootstrapProb.setSelectedIndex(0);
    else
      rbpBootstrapProb.setSelectedIndex(1);
  }

  public boolean isShowBootstrapValue() {
    if(rbpBootstrapProb.getSelectedIndex() == 0)
       return true;
    return false;
  }



  void jbInit() throws Exception {
    dppScaleFactor.setText("Scale factor (pixel/cM): ");
    dppScaleFactor.setValue(drawMapOptionBean.getScaleFactor());
    dppScaleFactor.setRange(DblParamPanel.VR_POSITIVE);
    ippMapSpacing.setText("Map spacing (pixels): ");
    ippMapSpacing.setValue(drawMapOptionBean.getMapSpacing());
    ippMapSpacing.setRange(IntParamPanel.VR_POSITIVE);
    ippMarginSize.setText("Margin size (pixels): ");
    ippMarginSize.setValue(drawMapOptionBean.getMarginSize());
    ippMarginSize.setRange(IntParamPanel.VR_POSITIVE);
    rbpBootstrapProb.setText("Show bootstrap probability: ");
    rbpBootstrapProb.addItem("Yes");
    rbpBootstrapProb.addItem("No");
    if(drawMapOptionBean.isShowBootstrapValue())
      rbpBootstrapProb.setSelectedIndex(0);
    else
      rbpBootstrapProb.setSelectedIndex(1);
    fcpGroupName.setText("Font for group name: ");
    fcpGroupName.setSelectedFont(drawMapOptionBean.getFontGroupName());
    fcpMarkerInfo.setText("Font for marker infomation: ");
    fcpMarkerInfo.setSelectedFont(drawMapOptionBean.getFontMarkerInfo());
    gridLayout1.setColumns(1);
    gridLayout1.setRows(7);
    this.setLayout(gridLayout1);
    this.add(dppScaleFactor, null);
    this.add(ippMapSpacing, null);
    this.add(ippMarginSize, null);
    this.add(rbpBootstrapProb, null);
    this.add(fcpGroupName, null);
    this.add(fcpMarkerInfo, null);
  }

}
