/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.antmap.gui;

import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

/**
 * <p>^Cg: </p>
 * <p>: </p>
 * <p>쌠: Copyright (c) 2004</p>
 * <p>Ж: </p>
 * @author 
 * @version 1.0
 */

public class FontChooser extends JDialog {
  private boolean applied = false;
  private Font defaultFont = new Font("Default", Font.PLAIN, 12);

  JPanel panel1 = new JPanel();
  GridLayout gridLayout1 = new GridLayout();
  IntParamPanel ippFontSize = new IntParamPanel();
  ComboBoxPanel cbpFontName = new ComboBoxPanel();
  ComboBoxPanel cbpFontStyle = new ComboBoxPanel();
  JPanel jPanel1 = new JPanel();
  JButton jButton_Applly = new JButton();
  JButton jButton_Cancel = new JButton();
  JPanel jPanel2 = new JPanel();
  JTextArea jTextArea1 = new JTextArea();
  JButton jButton_Preview = new JButton();

  public FontChooser(Frame frame, String title, boolean modal) {
    super(frame, title, modal);
    try {
      jbInit();
      pack();
      setDefaultInfo();
    }
    catch(Exception ex) {
      ex.printStackTrace();
    }
  }

  public FontChooser(Frame frame) {
    this(frame, "Font Chooser", false);
  }

  public FontChooser() {
    this(null, "Font Chooser", false);
  }

  private void jbInit() throws Exception {
    ippFontSize.setText("Size (points): ");
    ippFontSize.setRange(IntParamPanel.VR_POSITIVE);
    cbpFontName.setText("Name: ");
    cbpFontName.addItems(getAllFonts());
    cbpFontStyle.setText("Style: ");
    cbpFontStyle.addItem("Plain");
    cbpFontStyle.addItem("Bold");
    cbpFontStyle.addItem("Italic");
    cbpFontStyle.addItem("Bold Italic");
    panel1.setLayout(gridLayout1);
    gridLayout1.setColumns(1);
    gridLayout1.setRows(5);
    jButton_Applly.setText("Apply");
    jButton_Applly.addActionListener(new FontChooser_jButton_Applly_actionAdapter(this));
    jButton_Cancel.setText("Cancel");
    jButton_Cancel.addActionListener(new FontChooser_jButton_Cancel_actionAdapter(this));
    panel1.setPreferredSize(new Dimension(300, 240));
    this.setResizable(false);
    jTextArea1.setPreferredSize(new Dimension(250, 40));
    jTextArea1.setText(" abc ABC 123");
    jButton_Preview.setText("Preview");
    jButton_Preview.addActionListener(new FontChooser_jButton_Preview_actionAdapter(this));
    getContentPane().add(panel1);
    panel1.add(cbpFontName, null);
    panel1.add(cbpFontStyle, null);
    panel1.add(ippFontSize, null);
    panel1.add(jPanel2, null);
    jPanel2.add(jTextArea1, null);
    panel1.add(jPanel1, null);
    jPanel1.add(jButton_Applly, null);
    jPanel1.add(jButton_Preview, null);
    jPanel1.add(jButton_Cancel, null);
  }

  public void showDialog(Component parent) {
    this.setModal(true);
    int x, y;
    if(parent != null) {
      Point location = parent.getLocationOnScreen();
      x = location.x + parent.getWidth() / 2;
      y = location.y + parent.getHeight() / 2;
    } else {
      Dimension dim = getToolkit().getScreenSize();
      x = (int)dim.getWidth() / 2;
      y = (int)dim.getHeight() / 2;
    }
    x -= this.getWidth() / 2;
    y -= this.getHeight() / 2;
    this.setLocation(x, y);
    applied = false;
    this.show();
  }

  public void setDefaultFont(Font font) {
    defaultFont = font;
    setDefaultInfo();
  }

  private void setDefaultInfo() {
    cbpFontName.setSelectedItem(defaultFont.getName());
    cbpFontStyle.setSelectedIndex(defaultFont.getStyle());
    ippFontSize.setValue(defaultFont.getSize());
    preview();
  }

  public Font getSelectedFont() {
    return new Font((String)cbpFontName.getSelectedItem(),
                    cbpFontStyle.getSelectedIndex(),
                    ippFontSize.getValue());
  }

  public boolean isApplied() {
    return applied;
  }

  private String [] getAllFonts() {
    return GraphicsEnvironment.getLocalGraphicsEnvironment().getAvailableFontFamilyNames();
  }

  private void preview() {
    jTextArea1.setFont(getSelectedFont());
  }

  void jButton_Applly_actionPerformed(ActionEvent e) {
    applied = true;
    dispose();
    setVisible(false);
  }

  void jButton_Cancel_actionPerformed(ActionEvent e) {
    applied = false;
    setDefaultInfo();
    dispose();
    setVisible(false);
  }

  void jButton_Preview_actionPerformed(ActionEvent e) {
    jTextArea1.setFont(getSelectedFont());
  }

}

class FontChooser_jButton_Applly_actionAdapter implements java.awt.event.ActionListener {
  FontChooser adaptee;

  FontChooser_jButton_Applly_actionAdapter(FontChooser adaptee) {
    this.adaptee = adaptee;
  }
  public void actionPerformed(ActionEvent e) {
    adaptee.jButton_Applly_actionPerformed(e);
  }
}

class FontChooser_jButton_Cancel_actionAdapter implements java.awt.event.ActionListener {
  FontChooser adaptee;

  FontChooser_jButton_Cancel_actionAdapter(FontChooser adaptee) {
    this.adaptee = adaptee;
  }
  public void actionPerformed(ActionEvent e) {
    adaptee.jButton_Cancel_actionPerformed(e);
  }
}

class FontChooser_jButton_Preview_actionAdapter implements java.awt.event.ActionListener {
  FontChooser adaptee;

  FontChooser_jButton_Preview_actionAdapter(FontChooser adaptee) {
    this.adaptee = adaptee;
  }
  public void actionPerformed(ActionEvent e) {
    adaptee.jButton_Preview_actionPerformed(e);
  }
}
