/*
 AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
 Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

 Hiroyoshi IWATA
 Department of Information Science and Technology
 National Agricultural Research Center
 3-1-1 Kannondai
 Tsukuba
 Ibaraki 305-8666
 JAPAN

 ph        +81-298-38-7025
 fax       +81-298-38-8551
 e-mail    iwatah@affrc.go.jp
 */

package org.agmodel.bioinfo.antmap.gui;

import java.io.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import org.agmodel.bioinfo.antmap.*;
import org.agmodel.bioinfo.common.*;

/**
 * Main frame of AntMap
 * <p>Title: AntMap</p>
 * <p>Explanation: Linkage mapping software based on ACO algorithm</p>
 * <p>Copyright: Copyright (c) 2004 NARO</p>
 * <p>Company name: NARO</p>
 * @author Hiroyoshi IWATA
 * @version 1.1
 */
public class MainFrame
    extends JFrame {
  private final int SI_LOG = 0;
  private final int SI_DATA = 1;
  private final int SI_RESULT = 2;
  private final int SI_MAP = 3;
  //private final int SI_OPTION = 4;

  JPanel contentPane;
  BorderLayout borderLayout1 = new BorderLayout();
  JMenuBar jMenuBar = new JMenuBar();
  JMenu jMenu_File = new JMenu();
  JMenuItem jMenuItem_File_Open = new JMenuItem();
  JMenuItem jMenuItem_File_Exit = new JMenuItem();
  JMenu jMenu_Save = new JMenu();
  JMenuItem jMenuItem_Save_Result = new JMenuItem();
  JMenuItem jMenuItem_Save_Log = new JMenuItem();
  JMenu jMenu_Anal = new JMenu();
  JMenuItem jMenuItem_Anal_Seg = new JMenuItem();
  JMenuItem jMenuItem_Anal_Group = new JMenuItem();
  JMenuItem jMenuItem_Anal_Order = new JMenuItem();
  JMenuItem jMenuItem_Anal_Boot = new JMenuItem();
  JMenuItem jMenuItem_Anal_Full = new JMenuItem();
  JMenu jMenu_Help = new JMenu();
  JMenuItem jMenuItem_Help_About = new JMenuItem();
  JMenuItem jMenuItem_Help_Gpl = new JMenuItem();
  JTabbedPane jTabbedPane1 = new JTabbedPane();
  JScrollPane jScrollPane1 = new JScrollPane();
  MyTextArea myTextArea_log = new MyTextArea();
  JScrollPane jScrollPane2 = new JScrollPane();
  JTextArea jTextArea_data = new JTextArea();
  JScrollPane jScrollPane3 = new JScrollPane();
  MyTextArea myTextArea_result = new MyTextArea();
  JScrollPane jScrollPane4 = new JScrollPane();
  DrawMapPanel drawMapPanel = new DrawMapPanel();
  JFileChooser jFileChooser1 = new JFileChooser();
  AntMapOptionPanel antMapOptionPanel = new AntMapOptionPanel();
  JSplitPane jSplitPane1 = new JSplitPane();
  JLabel jLabel_Status = new JLabel();
  JProgressBar jProgressBar = new JProgressBar();

  //ŒǉIuWFNg
  AntMapEngine antMapEngine = new AntMapEngine(this);
  JMenuItem jMenuItem_Anal_Redraw = new JMenuItem();
  JMenuItem jMenuItem_Save_Map = new JMenuItem();

  //t[̃rh
  public MainFrame() {
    enableEvents(AWTEvent.WINDOW_EVENT_MASK);
    try {
      jbInit();
    }
    catch (Exception e) {
      e.printStackTrace();
    }
  }

  //R|[lg̏
  private void jbInit() throws Exception {
    contentPane = (JPanel)this.getContentPane();
    contentPane.setLayout(borderLayout1);
    this.setSize(new Dimension(640, 480));
    this.setTitle("Antmap");
    jMenu_File.setText("File");
    jMenuItem_File_Open.setText("Open");
    jMenuItem_File_Open.addActionListener(new
        MainFrame_jMenuItem_File_Open_actionAdapter(this));
    jMenuItem_File_Exit.setText("Exit");
    jMenuItem_File_Exit.addActionListener(new
        MainFrame_jMenuItem_File_Exit_actionAdapter(this));
    jMenu_Save.setText("Save");
    jMenuItem_Save_Result.setText("Result");
    jMenuItem_Save_Result.addActionListener(new
        MainFrame_jMenuItem_Save_Result_actionAdapter(this));
    jMenuItem_Save_Log.setText("Log");
    jMenuItem_Save_Log.addActionListener(new
        MainFrame_jMenuItem_Save_Log_actionAdapter(this));
    jMenu_Anal.setText("Analysis");
    jMenuItem_Anal_Seg.setText("Segregation Test");
    jMenuItem_Anal_Seg.addActionListener(new
        MainFrame_jMenuItem_Anal_Seg_actionAdapter(this));
    jMenuItem_Anal_Group.setText("Linkage Grouping");
    jMenuItem_Anal_Group.addActionListener(new
        MainFrame_jMenuItem_Anal_Group_actionAdapter(this));
    jMenuItem_Anal_Order.setText("Locus Ordering");
    jMenuItem_Anal_Order.addActionListener(new
        MainFrame_jMenuItem_Anal_Order_actionAdapter(this));
    jMenuItem_Anal_Boot.setText("Bootstrap Test");
    jMenuItem_Anal_Boot.addActionListener(new
        MainFrame_jMenuItem_Anal_Boot_actionAdapter(this));
    jMenuItem_Anal_Redraw.setText("Redraw Map");
    jMenuItem_Anal_Redraw.addActionListener(new
        MainFrame_jMenuItem_Anal_Redraw_actionAdapter(this));
    jMenuItem_Anal_Full.setText("Full Course");
    jMenuItem_Anal_Full.addActionListener(new
        MainFrame_jMenuItem_Anal_Full_actionAdapter(this));
    jMenu_Help.setText("Help");
    jMenuItem_Help_About.setText("About AntMap");
    jMenuItem_Help_About.addActionListener(new
        MainFrame_jMenuItem_Help_About_actionAdapter(this));
    jMenuItem_Help_Gpl.setText("About GPL");
    jMenuItem_Help_Gpl.addActionListener(new
        MainFrame_jMenuItem_Help_Gpl_actionAdapter(this));
    jTextArea_data.setEditable(false);
    jTextArea_data.setText("");
    jTextArea_data.setLineWrap(true);
    //jTextArea_log.setToolTipText("");
    myTextArea_log.setEditable(false);
    myTextArea_log.setText("");
    myTextArea_log.setLineWrap(true);
    myTextArea_result.setEditable(false);
    myTextArea_result.setText("");
    myTextArea_result.setLineWrap(true);
    jLabel_Status.setText("Please open a data file ...");
    jMenuItem_Save_Map.setText("Map");
    jMenuItem_Save_Map.addActionListener(new
        MainFrame_jMenuItem_Save_Map_actionAdapter(this));
    jMenuBar.add(jMenu_File);
    jMenuBar.add(jMenu_Anal);
    jMenuBar.add(jMenu_Help);
    jMenu_File.add(jMenuItem_File_Open);
    jMenu_File.addSeparator();
    jMenu_File.add(jMenu_Save);
    jMenu_File.addSeparator();
    jMenu_File.add(jMenuItem_File_Exit);
    jMenu_Anal.add(jMenuItem_Anal_Seg);
    jMenu_Anal.add(jMenuItem_Anal_Group);
    jMenu_Anal.add(jMenuItem_Anal_Order);
    jMenu_Anal.add(jMenuItem_Anal_Full);
    jMenu_Anal.addSeparator();
    jMenu_Anal.add(jMenuItem_Anal_Boot);
    jMenu_Anal.addSeparator();
    jMenu_Anal.add(jMenuItem_Anal_Redraw);
    jMenu_Help.add(jMenuItem_Help_About);
    jMenu_Help.addSeparator();
    jMenu_Help.add(jMenuItem_Help_Gpl);
    contentPane.add(jTabbedPane1, BorderLayout.CENTER);
    jTabbedPane1.add(jScrollPane1, "Log");
    jTabbedPane1.add(jScrollPane2, "Data");
    jTabbedPane1.add(jScrollPane3, "Result");
    jTabbedPane1.add(jScrollPane4, "Map");
    jTabbedPane1.add(antMapOptionPanel, "Options");
    contentPane.add(jSplitPane1, BorderLayout.SOUTH);
    jSplitPane1.add(jLabel_Status, JSplitPane.LEFT);
    jSplitPane1.add(jProgressBar, JSplitPane.RIGHT);
    jScrollPane4.getViewport().add(drawMapPanel, null);
    jScrollPane3.getViewport().add(myTextArea_result, null);
    jScrollPane2.getViewport().add(jTextArea_data, null);
    jScrollPane1.getViewport().add(myTextArea_log, null);
    jMenu_Save.add(jMenuItem_Save_Result);
    jMenu_Save.add(jMenuItem_Save_Log);
    jMenu_Save.add(jMenuItem_Save_Map);
    setJMenuBar(jMenuBar);
    jSplitPane1.setDividerLocation(200);
  }

  //EBhEꂽƂɏI悤ɃI[o[Ch
  protected void processWindowEvent(WindowEvent e) {
    super.processWindowEvent(e);
    if (e.getID() == WindowEvent.WINDOW_CLOSING) {
      System.exit(0);
    }
  }

  private boolean confirmOverwrite(File file) {
    if (file.exists()) {
      int answer = JOptionPane.showConfirmDialog(this,
                                                 file.getName() +
                                                 " already exists.\n" +
                                                 "Overwrite " + file.getName() +
                                                 " ?",
                                                 "Confirmation",
                                                 JOptionPane.YES_NO_OPTION,
                                                 JOptionPane.QUESTION_MESSAGE);
      if (answer == JOptionPane.NO_OPTION) {
        JOptionPane.showMessageDialog(this,
                                      "Stop saving your data to " +
                                      file.getName() + ".\n" +
                                      "Please try again.",
                                      "Confirmation",
                                      JOptionPane.INFORMATION_MESSAGE);
        return false;
      }
    }
    return true;
  }

  private String checkExtension(String fileName, MyFileFilter myFileFilter) {
    File file = new File(fileName);
    if (!myFileFilter.accept(file)) {
      fileName = file.getPath() + "." + myFileFilter.getExtension();
    }
    return fileName;
  }

  void jMenuItem_File_Open_actionPerformed(ActionEvent e) {
    jTabbedPane1.setSelectedIndex(SI_LOG);
    jLabel_Status.setText("load and verify data ...");
    jFileChooser1.setDialogTitle("Open data file");
    jFileChooser1.setSelectedFile(new File(""));
    jFileChooser1.setFileFilter(new MyFileFilter("raw", "Mapmaker file (*.raw)"));
    if (jFileChooser1.showOpenDialog(this) == JFileChooser.APPROVE_OPTION) {
      File file = new File(jFileChooser1.getSelectedFile().getPath());
      if (file.exists()) {
        try {
          FileReader fr = new FileReader(file);
          BufferedReader br = new BufferedReader(fr);
          jTextArea_data.setText("");
          while (br.ready()) {
            String line = br.readLine();
            jTextArea_data.append(line + "\n");
          }
          fr.close();
          jTextArea_data.setCaretPosition(0);
          antMapOptionPanel.setOrderingGroupNames(null);
          antMapEngine.loadData(file.getPath());
          jTabbedPane1.setSelectedIndex(SI_DATA);
        }
        catch (AntMapEngineException ex) {
          JOptionPane.showMessageDialog(this, ex.getMessage(), "Ant Map Error",
                                        JOptionPane.ERROR_MESSAGE);
        }
        catch (FileFormatException ex) {
          JOptionPane.showMessageDialog(this, ex.getMessage(),
                                        "File Format Error",
                                        JOptionPane.ERROR_MESSAGE);
        }
        catch (Exception ex) {
          JOptionPane.showMessageDialog(this, ex, "Error!",
                                        JOptionPane.ERROR_MESSAGE);
        }
      }
      else {
        JOptionPane.showMessageDialog(this,
                                      file.getName() + " cannot be not found.",
                                      "File Error",
                                      JOptionPane.ERROR_MESSAGE);
      }
    }
    myTextArea_log.setCaretPosition(myTextArea_log.getText().length());
    myTextArea_result.setCaretPosition(myTextArea_result.getText().length());
    jFileChooser1.resetChoosableFileFilters();
    jLabel_Status.setText("ready ...");
  }

  void jMenuItem_Save_Result_actionPerformed(ActionEvent e) {
    jTabbedPane1.setSelectedIndex(SI_RESULT);
    jLabel_Status.setText("save result ...");
    jFileChooser1.setDialogTitle("Save result to file");
    jFileChooser1.setSelectedFile(new File(""));
    MyFileFilter myFileFilter = new MyFileFilter("txt", "Text file (*.txt)");
    jFileChooser1.setFileFilter(myFileFilter);
    //jFileChooser1.setFileFilter(new MyFileFilter("txt", "Text file (*.txt)"));
    if (jFileChooser1.showSaveDialog(this) == JFileChooser.APPROVE_OPTION) {
      //File file = new File(jFileChooser1.getSelectedFile().getPath());
      File file = new File(checkExtension(jFileChooser1.getSelectedFile().
                                          getPath(), myFileFilter));
      if (confirmOverwrite(file)) {
        try {
          myTextArea_result.saveText(file);
        }
        catch (Exception ex) {
          JOptionPane.showMessageDialog(this, ex, "Error",
                                        JOptionPane.ERROR_MESSAGE);
        }
      }
    }
    jFileChooser1.resetChoosableFileFilters();
    jLabel_Status.setText("ready ...");
  }

  void jMenuItem_Save_Log_actionPerformed(ActionEvent e) {
    jTabbedPane1.setSelectedIndex(SI_LOG);
    jLabel_Status.setText("save log ...");
    jFileChooser1.setDialogTitle("Save log to file");
    jFileChooser1.setSelectedFile(new File(""));
    MyFileFilter myFileFilter = new MyFileFilter("txt", "Text file (*.txt)");
    jFileChooser1.setFileFilter(myFileFilter);
    //jFileChooser1.setFileFilter(new MyFileFilter("txt", "Text file (*.txt)"));
    if (jFileChooser1.showSaveDialog(this) == JFileChooser.APPROVE_OPTION) {
      //File file = new File(jFileChooser1.getSelectedFile().getPath());
      File file = new File(checkExtension(jFileChooser1.getSelectedFile().
                                          getPath(), myFileFilter));
      if (confirmOverwrite(file)) {
        try {
          myTextArea_log.saveText(file);
        }
        catch (Exception ex) {
          JOptionPane.showMessageDialog(this, ex, "Error",
                                        JOptionPane.ERROR_MESSAGE);
        }
      }
    }
    jFileChooser1.resetChoosableFileFilters();
    jLabel_Status.setText("ready ...");
  }

  void jMenuItem_Save_Map_actionPerformed(ActionEvent e) {
    jTabbedPane1.setSelectedIndex(SI_MAP);
    jLabel_Status.setText("save map ...");
    jFileChooser1.setDialogTitle("Save map as JPEG image");
    jFileChooser1.setSelectedFile(new File(""));
    MyFileFilter myFileFilter = new MyFileFilter("jpg", "JPEG file (*.jpg)");
    jFileChooser1.setFileFilter(myFileFilter);
    if (jFileChooser1.showSaveDialog(this) == JFileChooser.APPROVE_OPTION) {
      //File file = new File(jFileChooser1.getSelectedFile().getPath());
      File file = new File(checkExtension(jFileChooser1.getSelectedFile().
                                          getPath(), myFileFilter));
      if (confirmOverwrite(file)) {
        try {
          drawMapPanel.saveImage(file, 1.0f);
        }
        catch (Exception ex) {
          JOptionPane.showMessageDialog(this, ex, "Error",
                                        JOptionPane.ERROR_MESSAGE);
        }
      }
    }
    jFileChooser1.resetChoosableFileFilters();
    jLabel_Status.setText("ready ...");
  }

  //Exitj[EBhE
  void jMenuItem_File_Exit_actionPerformed(ActionEvent e) {
    System.exit(0);
  }

  void jMenuItem_Anal_Seg_actionPerformed(ActionEvent e) {
    jTabbedPane1.setSelectedIndex(SI_LOG);
    jLabel_Status.setText("test segregation ...");
    try {
      antMapEngine.testSegregation();
      jTabbedPane1.setSelectedIndex(SI_RESULT);
    }
    catch (AntMapEngineException ex) {
      JOptionPane.showMessageDialog(this, ex.getMessage(), "Ant Map Error",
                                    JOptionPane.ERROR_MESSAGE);
    }
    catch (Exception ex) {
      JOptionPane.showMessageDialog(this, ex, "Error",
                                    JOptionPane.ERROR_MESSAGE);
    }
    myTextArea_log.setCaretPosition(myTextArea_log.getText().length());
    myTextArea_result.setCaretPosition(myTextArea_result.getText().length());
    jLabel_Status.setText("ready ...");
  }

  void jMenuItem_Anal_Group_actionPerformed(ActionEvent e) {
    jTabbedPane1.setSelectedIndex(SI_LOG);
    jLabel_Status.setText("linkage grouping ...");
    GroupingOptionBean groupingOptionBean = antMapOptionPanel.
        getGroupingOptionBean();
    try {
      int nGroup = antMapEngine.linkageGrouping(groupingOptionBean);
      if (nGroup > 0) {
        String[] groupName = new String[nGroup];
        for (int i = 0; i < nGroup; i++) {
          groupName[i] = "Group" + (i + 1);
        }
        antMapOptionPanel.setOrderingGroupNames(groupName);
      }
      jTabbedPane1.setSelectedIndex(SI_RESULT);
    }
    catch (AntMapEngineException ex) {
      JOptionPane.showMessageDialog(this, ex.getMessage(), "Ant Map Error",
                                    JOptionPane.ERROR_MESSAGE);
    }
    catch (Exception ex) {
      JOptionPane.showMessageDialog(this, ex, "Error",
                                    JOptionPane.ERROR_MESSAGE);
    }
    myTextArea_log.setCaretPosition(myTextArea_log.getText().length());
    myTextArea_result.setCaretPosition(myTextArea_result.getText().length());
    jLabel_Status.setText("ready ...");
  }

  void jMenuItem_Anal_Order_actionPerformed(ActionEvent e) {
    jTabbedPane1.setSelectedIndex(SI_LOG);
    jLabel_Status.setText("locus ordering ...");
    OrderingOptionBean orderingOptionBean = antMapOptionPanel.
        getOrderingOptionBean();
    AcoParamsBean acoParamsBean = antMapOptionPanel.getAcoParamsBean();
    drawMapPanel.setDrawMapOptionBean(antMapOptionPanel.getDrawMapOptionBean());
    try {
      antMapEngine.locusOrdering(orderingOptionBean, acoParamsBean);
      jTabbedPane1.setSelectedIndex(SI_RESULT);
    }
    catch (AntMapEngineException ex) {
      JOptionPane.showMessageDialog(this, ex.getMessage(), "Ant Map Error",
                                    JOptionPane.ERROR_MESSAGE);
    }
    catch (Exception ex) {
      JOptionPane.showMessageDialog(this, ex, "Error",
                                    JOptionPane.ERROR_MESSAGE);
    }
    myTextArea_log.setCaretPosition(myTextArea_log.getText().length());
    myTextArea_result.setCaretPosition(myTextArea_result.getText().length());
  }

  void jMenuItem_Anal_Boot_actionPerformed(ActionEvent e) {
    jTabbedPane1.setSelectedIndex(SI_LOG);
    jLabel_Status.setText("boot strap test ...");
    OrderingOptionBean orderingOptionBean = antMapOptionPanel.
        getOrderingOptionBean();
    AcoParamsBean acoParamsBean = antMapOptionPanel.getAcoParamsBean();
    drawMapPanel.setDrawMapOptionBean(antMapOptionPanel.getDrawMapOptionBean());
    try {
      antMapEngine.bootstrapTest(orderingOptionBean, acoParamsBean);
      antMapOptionPanel.setDrawMapOptionBean(drawMapPanel.getDrawMapOptionBean());
      jTabbedPane1.setSelectedIndex(SI_RESULT);
    }
    catch (AntMapEngineException ex) {
      JOptionPane.showMessageDialog(this, ex.getMessage(), "Ant Map Error",
                                    JOptionPane.ERROR_MESSAGE);
    }
    catch (Exception ex) {
      JOptionPane.showMessageDialog(this, ex, "Error",
                                    JOptionPane.ERROR_MESSAGE);
    }
    myTextArea_log.setCaretPosition(myTextArea_log.getText().length());
    myTextArea_result.setCaretPosition(myTextArea_result.getText().length());
  }

  void jMenuItem_Anal_Full_actionPerformed(ActionEvent e) {

    jMenuItem_Anal_Seg_actionPerformed(e);
    jMenuItem_Anal_Group_actionPerformed(e);
    jMenuItem_Anal_Order_actionPerformed(e);
  }

  void jMenuItem_Anal_Redraw_actionPerformed(ActionEvent e) {
    jLabel_Status.setText("Redraw map ...");
    drawMapPanel.setDrawMapOptionBean(antMapOptionPanel.getDrawMapOptionBean());
    try {
      antMapEngine.redrawMap();
      if (jTabbedPane1.getSelectedIndex() == SI_MAP) {
        drawMapPanel.repaint();
      }
      else {
        jTabbedPane1.setSelectedIndex(SI_MAP);
      }
    }
    catch (AntMapEngineException ex) {
      JOptionPane.showMessageDialog(this, ex.getMessage(), "Ant Map Error",
                                    JOptionPane.ERROR_MESSAGE);
    }
    catch (Exception ex) {
      JOptionPane.showMessageDialog(this, ex, "Error",
                                    JOptionPane.ERROR_MESSAGE);
    }
    jLabel_Status.setText("ready ...");
  }

  void jMenuItem_Help_About_actionPerformed(ActionEvent e) {
    AntMapInfo ami = new AntMapInfo();
    String message = ami.getName();
    message += " Ver. " + ami.getVersion() + "\n";
    message += "Copyright: " + ami.getCopyright() + "\n";
    message += "Web site: " + ami.getWebAddress() + "\n";
    message += "Contact address (e-mail): " + ami.getContactAddress() + "\n";
    message += ami.getGplNotice();
    JOptionPane.showMessageDialog(this, message, "Version information",
                                  JOptionPane.INFORMATION_MESSAGE);
  }

  void jMenuItem_Help_Gpl_actionPerformed(ActionEvent e) {
    AboutGplDialog agf = new AboutGplDialog();
    agf.showDialog(this);
  }

}

class MainFrame_jMenuItem_File_Exit_actionAdapter
    implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItem_File_Exit_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItem_File_Exit_actionPerformed(e);
  }
}

class MainFrame_jMenuItem_File_Open_actionAdapter
    implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItem_File_Open_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItem_File_Open_actionPerformed(e);
  }
}

class MainFrame_jMenuItem_Anal_Seg_actionAdapter
    implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItem_Anal_Seg_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItem_Anal_Seg_actionPerformed(e);
  }
}

class MainFrame_jMenuItem_Anal_Group_actionAdapter
    implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItem_Anal_Group_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItem_Anal_Group_actionPerformed(e);
  }
}

class MainFrame_jMenuItem_Help_About_actionAdapter
    implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItem_Help_About_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItem_Help_About_actionPerformed(e);
  }
}

class MainFrame_jMenuItem_Help_Gpl_actionAdapter
    implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItem_Help_Gpl_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItem_Help_Gpl_actionPerformed(e);
  }
}

class MainFrame_jMenuItem_Save_Result_actionAdapter
    implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItem_Save_Result_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItem_Save_Result_actionPerformed(e);
  }
}

class MainFrame_jMenuItem_Save_Log_actionAdapter
    implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItem_Save_Log_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItem_Save_Log_actionPerformed(e);
  }
}

class MainFrame_jMenuItem_Anal_Order_actionAdapter
    implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItem_Anal_Order_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItem_Anal_Order_actionPerformed(e);
  }
}

class MainFrame_jMenuItem_Anal_Boot_actionAdapter
    implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItem_Anal_Boot_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItem_Anal_Boot_actionPerformed(e);
  }
}

class MainFrame_jMenuItem_Anal_Full_actionAdapter
    implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItem_Anal_Full_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItem_Anal_Full_actionPerformed(e);
  }
}

class MainFrame_jMenuItem_Anal_Redraw_actionAdapter
    implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItem_Anal_Redraw_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItem_Anal_Redraw_actionPerformed(e);
  }
}

class MainFrame_jMenuItem_Save_Map_actionAdapter
    implements java.awt.event.ActionListener {
  MainFrame adaptee;

  MainFrame_jMenuItem_Save_Map_actionAdapter(MainFrame adaptee) {
    this.adaptee = adaptee;
  }

  public void actionPerformed(ActionEvent e) {
    adaptee.jMenuItem_Save_Map_actionPerformed(e);
  }
}
