/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.common;

import java.io.Serializable;

/**
 * @author iwata
 *
 */
public class BisectionBean implements Serializable {

	public BisectionBean() {
	}

	public interface Function {
		public double of(double x);
	}

	private static boolean isSameSign(double a, double b) {
		return (a > 0) == (b > 0);
	}

	public static double solve(Function f, double a, double b, double tolerance) {

		if(tolerance < 0)
			tolerance = 0;

		if(b < a) {
			double swap = a;
			a = b;
			b = swap;
		}

		double fa = f.of(a);
		if(fa == 0)
			return a;
		double fb = f.of(b);
		if(fb == 0)
			return b;
		if(isSameSign(fa, fb))
			throw new Error("The function f has the same sign both on a and b");

		while(true) {
			double c = (a + b) / 2;
			if(c - a <= tolerance || b - c <= tolerance) return c;

			double fc = f.of(c);
			if(fc == 0)
				return c;

			if(isSameSign(fc, fa)) {
				a = c;
				fa = fc;
			} else {
				b = c;
				fb = fc;
			}
		}
	}
}
