/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.segregation;

/**
 * @author iwata
 *
 */
public class SegRatioBean implements java.io.Serializable {
	private int segType = SegType.ST_NA;
	private int markerType = MarkerType.MT_NA;
	private int n_data = 0;
	private int n_miss = 0;
	private char [] genotype = new char[1];
	private int [] n_obs = new int[1];
	private double [] n_exp = new double[1];
	private double chiSqr = 0.0;
	private double p = 0.0;

	/**
	 * Constructor
	 *
	 */
	public SegRatioBean() {

	}

	/**
	 * get observed ratio
	 * @return
	 */
	public String getObsRatio() {
		String obsRatio = "" + n_obs[0];
		for(int i = 1; i < n_obs.length; i++ ) {
			//obsRatio.concat(":" + n_obs[i]);
			obsRatio = obsRatio + ":" + n_obs[i];
		}
		return obsRatio;
	}

	/**
	 * get observed ratio
	 * @return
	 */
	public String getExpRatio() {
		String expRatio = "" + n_exp[0];
		for(int i = 1; i < n_exp.length; i++ ) {
			expRatio.concat(":" + n_exp[i]);
		}
		return expRatio;
	}

	/**
	 * get starts for significance test
	 * @return result string
	 */
	public String getSigStars() {
		if(p < 0.001) {
			return "***";
		} else if(p < 0.01) {
			return "**";
		} else if(p < 0.05) {
			return "*";
		}
		return "";
	}

	/**
	 * get the number of valid data
	 * @return
	 */
	public int getN_valid() {
		return n_data - n_miss;
	}


	/**
	 * @return
	 */
	public double getChiSqr() {
		return chiSqr;
	}

	/**
	 * @return
	 */
	public int getMarkerType() {
		return markerType;
	}

	/**
	 * @return
	 */
	public int getN_data() {
		return n_data;
	}

	/**
	 * @return
	 */
	public double[] getN_exp() {
		return n_exp;
	}

	/**
	 * @return
	 */
	public int getN_miss() {
		return n_miss;
	}

	/**
	 * @return
	 */
	public int[] getN_obs() {
		return n_obs;
	}

	/**
	 * @return
	 */
	public double getP() {
		return p;
	}

	/**
	 * @return
	 */
	public int getSegType() {
		return segType;
	}

	/**
	 * @param d
	 */
	public void setChiSqr(double d) {
		chiSqr = d;
	}

	/**
	 * @param i
	 */
	public void setMarkerType(int i) {
		markerType = i;
	}

	/**
	 * @param i
	 */
	public void setN_data(int i) {
		n_data = i;
	}

	/**
	 * @param ds
	 */
	public void setN_exp(double[] ds) {
		n_exp = ds;
	}

	/**
	 * @param i
	 */
	public void setN_miss(int i) {
		n_miss = i;
	}

	/**
	 * @param is
	 */
	public void setN_obs(int[] is) {
		n_obs = is;
	}

	/**
	 * @param d
	 */
	public void setP(double d) {
		p = d;
	}

	/**
	 * @param i
	 */
	public void setSegType(int i) {
		segType = i;
	}

	/**
	 * @return
	 */
	public char[] getGenotype() {
		return genotype;
	}

	/**
	 * @param cs
	 */
	public void setGenotype(char[] cs) {
		genotype = cs;
	}

}
