/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.stat.dist;

/**
 * @author iwata
 * Class for getting probabity related to Chi-square distribution
 * JavaASYTiZp]_Ёjp
 */
public class ChiSquareDist {

    /**
     * Calculate upper probability
     * @param df Degree of freedom
     * @param chi2 Chi-square value
     * @return Upper probability
     */
	public static double getUpperProb(int df, double chi2) {
		if((df & 1) != 0) {
			double chi = Math.sqrt(chi2);
			if(df == 1) return 2 * NormalDist.getUpperProb(chi);
			double s = chi * Math.exp(-0.5 * chi2) / Math.sqrt(2 * Math.PI);
			double t = s;
			for(int k = 3; k < df; k += 2) {
				t *= chi2 / k;
				s += t;
			}
			return 2 * (NormalDist.getUpperProb(chi) + s);
		} else {
			double s = Math.exp(-0.5 * chi2);
			double t = s;
			for(int k = 2; k < df; k += 2) {
				t *= chi2 / k;
				s += t;
			}
			return s;
		}
	}

	/**
	 * Calculate lower probability
	 * @param df Degreee of freedom
	 * @param chi2 Chi-square value
	 * @return Lower probability
	 */
	public static double getLowerProb(int df, double chi2) {
		return 1 - getUpperProb(df, chi2);
	}

}
