/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.stat.dist;

/**
 * @author iwata
 * Class for getting probability related to normal distribution
 * JavaASYTiZp]_Ёjp
 */
public class NormalDist {
	/**
	 * Calculate lower probability for normal distribution
	 * @param z z value
	 * @return Lower probability
	 */
	public static double getLowerProb(double z) {
		double z2 = z * z;
		double t = z * Math.exp(-0.5 * z2) / Math.sqrt(2 * Math.PI);
		double p = t;
		for(int i = 3; i < 200; i += 2) {
			double prev = p;
			t *= z2 / i;
			p += t;
			if(p == prev)
				return 0.5 + p;
		}
		return (z > 0) ? 1 : 0;
	}

	/**
	 * Calculate upper probability for normal distribution
	 * @param z z value
	 * @return Upper probability
	 */
	public static double getUpperProb(double z) {
		return 1 - getLowerProb(z);
	}
}
