/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.stat.test;

import org.agmodel.bioinfo.stat.dist.ChiSquareDist;

/**
 * @author iwata
 * Class to perform Chi-square test for goodness of fit
 */
public class GOFChiSqrTest {
	private int n_class;
	private int [] n_obs;
	private double [] n_exp;
	private double chiSqr = 0.0;
	private boolean calcChiSqr = false;

	/**
	 * Constructor
	 * @param n_obs Observed number for each class
	 * @param n_exp Expected number for each class
	 */
	public GOFChiSqrTest(int [] n_obs, double [] n_exp) {
		n_class = n_obs.length;
		this.n_obs = n_obs;
		this.n_exp = n_exp;
	}

	/**
	 * Get probability under null hypothesis,
	 * @return P-value
	 */
	public double getP() {
		if(!calcChiSqr) {
			chiSqr = getChiSqr();
		}
		return ChiSquareDist.getUpperProb(n_class - 1, chiSqr);
	}

	/**
	 * Get chi-square value
	 * @return chi-square value
	 */
	public double getChiSqr() {
		chiSqr = 0.0;
		for(int i = 0; i < n_class; i++ ) {
			if(n_exp[i] == 0.0)
				return -1.0;
			chiSqr += (n_obs[i] - n_exp[i]) * (n_obs[i] - n_exp[i]) / n_exp[i];
		}
		calcChiSqr = true;
		return chiSqr;
	}
}
