/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.test;

import org.agmodel.bioinfo.segregation.*;
import java.util.List;
import java.util.Iterator;
import java.util.Random;

/**
 * @author iwata
 *
 */
public class SegSimulator {

	public static void main(String[] args) {
		Random random = new Random();
		SegDataFactory segDataFactory = new SegDataFactory();

		for(int i = 0; i < 6; i++ ) {
			int nMarker = 10 + random.nextInt(12);
			Chromosome chr = new Chromosome("chr" + (i + 1));
			for(int j = 0; j < nMarker; j++ ) {
				Marker mrk = new Marker("C" + (i + 1) + "M" + (j + 1));

				if(random.nextDouble() < 0.04) {
					mrk.setType(MarkerType.MT_DOM_P1);
				}
				if(random.nextDouble() < 0.04) {
					mrk.setType(MarkerType.MT_DOM_P2);
				}

				chr.addMarker(mrk, 0.05 * j + 0.05 * random.nextDouble());
			}
			segDataFactory.addChromosome(chr);
		}
		/*
		Chromosome chr1 = new Chromosome("chr1");
		for(int i = 0; i < 10; i++ ) {
			Marker mrk = new Marker("C1M" + (i + 1));
			chr1.addMarker(mrk, 0.1 * i);
		}
		Chromosome chr2 = new Chromosome("chr2");
		for(int i = 0; i < 6; i++ ) {
			Marker mrk = new Marker("C2M" + (i + 1));
			chr2.addMarker(mrk, 0.1 * i);
		}

		segDataFactory.addChromosome(chr1);
		segDataFactory.addChromosome(chr2);
		*/
		List message = segDataFactory.getSegData(160, SegType.ST_F2, 0.04);
		Iterator iterator = message.iterator();
		while(iterator.hasNext()) {
			System.out.println((String) iterator.next());
		}



	}
}
