/*
AntMap: Software for constructing genetic linkage maps using an Ant Colony Optimization (ACO) algorithm
Copyright (C) 2004 National Agricultural and Bio-oriented Research Organization (NARO)

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Hiroyoshi IWATA
Department of Information Science and Technology
National Agricultural Research Center
3-1-1 Kannondai
Tsukuba
Ibaraki 305-8666
JAPAN

ph        +81-298-38-7025
fax       +81-298-38-8551
e-mail    iwatah@affrc.go.jp
*/

package org.agmodel.bioinfo.test;

import org.agmodel.bioinfo.antmap.*;
import org.agmodel.bioinfo.segregation.SegType;
import org.agmodel.bioinfo.segregation.MapFunction;

/**
 * @author iwata
 *
 */
public class TestAntMap2 {

	public static void main(String[] args) {
		//AntMapEngine antMapEngine = new AntMapEngine();

		SegDataBean segDataBean;

		if(args.length != 1) {
			System.out.println("Usage: TestAntMap2 <filename>");
			System.exit(-1);
		}
		try {
			long start = System.currentTimeMillis();
			String [] message;

			//f[^̃[h
			segDataBean = new SegDataReader(args[0]).getSegData("Mapmaker");
			System.out.println("Generation; " + SegType.getSegTypeName(segDataBean.getSegType()));
			System.out.println("# progenies: " + segDataBean.getN_individual());
			System.out.println("# markers: " + segDataBean.getN_marker());

			//f[^̃xt@C
			message = new SegDataVerifier().verify(segDataBean);
			showMessage(message);
			if(message.length > 0) {
				System.out.println(message.length + " error(s) in segregation data.");
				System.exit(-1);
			}
			message = null;

			//
			System.out.println("Segregation test: ");
			message = new SegRatioTester().testAllLoci(segDataBean);
			showMessage(message);
			message = null;

			//AO[sO
			System.out.println("Linkage grouping: ");
			GroupExtractor groupExtractor = new LGFactory().getGroupExtractor(segDataBean,
																			LGFactory.ME_NNL,
																			LGFactory.CR_R,
																			new MapFunction().getHaldaneRate(0.2),
																			3);
			int n_group = groupExtractor.getN_group();
			System.out.println("# groups: " + n_group);

			//ACOp}bsO
			//AcoParamsBean acoParams = new AcoParamsReader().loadAcoParamsBean("c:\\eclipse\\workspace\\bioinfo\\etc\\acoparams.txt");
			AcoParamsBean acoParams = new AcoParamsBean();
			AcoMapFactory acoMapFactory = new AcoMapFactory(acoParams);
			MapData [] mapData = new MapData [n_group];
			for(int i = 0; i < n_group; i++ ) {
				System.out.println("Group" + (i + 1) + ": ");
				int [] markerIndex = groupExtractor.getMarkerIndices(i);
				mapData[i] = acoMapFactory.getBestMap(segDataBean, markerIndex, 10, 2);
				mapData[i].showLocation();
			}
			groupExtractor = null;

			//u[gXgbv
			/*
			BootStrapTester bootStrapTester = new BootStrapTester(acoMapFactory);
			for(int i = 0; i < n_group; i++ ) {
				System.out.println("Group " + (i + 1) + ": ");
				bootStrapTester.testOrder(segDataBean, mapData[i], 20, 3, 10);
				mapData[i].showBootProb();
			}
			mapData = null;
			bootStrapTester = null;
			acoMapFactory = null;
			segDataBean = null;
			*/

			long stop = System.currentTimeMillis();
			System.out.println("sɂԂ" + (double)(stop - start) / 1000 + "błB");
		} catch (Exception e){
			System.out.println("Exception :" + e);
			e.printStackTrace();
		}





	}

	private static void showMessage(String [] message) {
		for(int i = 0; i < message.length; i++ )
			System.out.println(message[i]);
	}

}
